Documentation
¶
Index ¶
- func GetHTMLTag(data []byte, maxpos uint64) ([]byte, error)
- func GetHTMLTagString(s string, maxpos uint64) (string, error)
- func HTMLIndex(data []byte, maxpos uint64) (uint64, error)
- func HTMLIndexString(s string, maxpos uint64) (uint64, error)
- func HasHTMLTag(data []byte, maxpos uint64) bool
- func HasHTMLTagString(s string, maxpos uint64) bool
- func HasScriptTag(data []byte, maxpos uint64) bool
- func HasScriptTagString(s string, maxpos uint64) bool
- func IsHTML(data []byte) bool
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HasHTMLTag ¶
HasHTMLTag checks if the literal <html[...]> tag exists in the given data, within the given max character position.
func HasHTMLTagString ¶
func HasScriptTag ¶
HasScriptTag checks if the literal <script> tag exists in the given data, within the given max character position.
func HasScriptTagString ¶
HasScriptTagString checks if the literal <script> tag exists in the given string, within the given max rune position.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.